@@ -5,11 +5,11 @@ from serial.tools import list_ports
 
 class UartManager:
 
-    def __init__(self, port = None, baudRate = 230400):
-        self.port = port
-        self.baudRate = baudRate
+    def __init__(self, loop = None):
+        self.port = None
+        self.baudRate = 230400
         self.running = True
-        self._trackingLoop = None
+        self._trackingLoop = loop
         self._availablePorts = list(list_ports.comports())
         self._attemptingIndex = 0
         self._uartBridge = None
@@ -44,6 +44,8 @@ class UartManager:
                 index += 1
             if not found_port:
                 return await self.setupConnection(port)
+            else:
+                await self._attemptConnection(self._attemptingIndex, False)
 
 
         if self._trackingLoop is None:
@@ -58,17 +60,19 @@ class UartManager:
                 await self._attemptConnection(self._attemptingIndex)
 
 
-    async def _attemptConnection(self, index):
+    async def _attemptConnection(self, index, handshake=True):
         attemptingPort = self._availablePorts[index]
-        await self.setupConnection(attemptingPort.device)
+        await self.setupConnection(attemptingPort.device, handshake)
 
 
-    async def setupConnection(self, port):
+    async def setupConnection(self, port, handshake=True):
         self._uartBridge = UartBridge(port, self.baudRate)
         self._uartBridge.start()
         await self._uartBridge.starting()
+        success = True
 
-        success = await self._uartBridge.handshake()
+        if handshake:
+            success = await self._uartBridge.handshake()
 
         if not success:
             print("Crownstone handshake failed. Moving on to next device...")
@@ -80,13 +84,13 @@ class UartManager:
             print("Connection established to", port)
             self.port = port
             self.ready = True
-            asyncio.create_task(self.trackConnection())
+            asyncio.ensure_future(self.trackConnection())
         
 
     async def trackConnection(self):
         await self._uartBridge.isAlive()
         if self.running:
-            asyncio.create_task(self.reset())
+            asyncio.ensure_future(self.reset())
 
 
     def is_ready(self) -> bool:
